
# Slot: edge_list_is_sorted


Whether the edge list is sorted. Note that a sorted edge list has the minimal memory peak, but requires the nodes number and the edges number.

URI: [https://w3id.org/neat/ensmallenRunConfig__edge_list_is_sorted](https://w3id.org/neat/ensmallenRunConfig__edge_list_is_sorted)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
